<?php
// API doc : https://coincheck.com/ja/documents/exchange/api#buy-rate
// API url : https://coincheck.com/api/rate/[pair]

// rate api url
$coincheck_api_url  = "https://coincheck.com/api/rate";
$cryptocurrencies = array(
    "btc_jpy", "eth_jpy", "etc_jpy", "dao_jpy", "lsk_jpy",
    "fct_jpy", "xmr_jpy", "rep_jpy", "xrp_jpy", "zec_jpy",
    "xem_jpy", "ltc_jpy", "dash_jpy","bch_jpy", "eth_btc",
    "etc_btc", "lsk_btc", "fct_btc", "xmr_btc", "rep_btc",
    "xrp_btc", "zec_btc", "xem_btc", "ltc_btc", "dash_btc",
    "bch_btc"
);

$options = getopt("p:");
if (!check_arguments($options, $cryptocurrencies)) {
    usage($cryptocurrencies);
    die(1);
}

// proxy settings
$proxy      = "";
$proxy_port = "";

$curl = curl_init();
if ($curl == FALSE) {
    fputs(STDERR, "[ERR] curl_init(): " . curl_error($curl) . PHP_EOL);
    die(1);
}

if (empty($options)) {
    $target_pair = $cryptocurrencies;
} else {
    $target_pair = array($options["p"]);
}

$pair_rate = array();
foreach ($target_pair as $pair) {
    // curl set options
    curl_setopt($curl, CURLOPT_URL, $coincheck_api_url . "/" . $pair);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);
    // set proxy server settings
    if (!empty($proxy) && !empty($proxy_port)) {
        curl_setopt($curl, CURLOPT_HTTPPROXYTUNNEL, 1);
        curl_setopt($curl, CURLOPT_PROXY, $proxy . ":" . $proxy_port);
        curl_setopt($curl, CURLOPT_PROXYPORT, $proxy_port);
    }

    // call order book api
    $response = curl_exec($curl);
    if ($response == FALSE) {
        fputs(STDERR, "[ERR] curl_exec(): " . curl_error($curl) . PHP_EOL);
        die(1);
    }
    // json decode
    $json_decode = json_decode($response, true);
    if ($json_decode == NULL) {
        fputs(STDERR, "[ERR] json_decode(): " . json_last_error_msg() . PHP_EOL);
        die(1);
    }
    $pair_rate[$pair] = $json_decode["rate"];
}
curl_close($curl);

// show rate
print_r($pair_rate);
exit(0);

//----------------------------------------------------------
// functions
//----------------------------------------------------------
function check_arguments($options, $cryptocurrencies) {
    if (array_key_exists('p' ,$options)) {
        if (!(in_array($options["p"] ,$cryptocurrencies))) {
            return FALSE;
        }
    }
    return TRUE;
}

function usage($cryptocurrencies) {
    $usage =
    "Uasge: php rate.php [-p pair]" . PHP_EOL .
    "Options:" . PHP_EOL .
    "  -p pair" . PHP_EOL .
    "e.g." . PHP_EOL .
    "  php rate.php            : show all pair rate.". PHP_EOL .
    "  php rate.php -p btc_jpy : show BTC/JPY rate.". PHP_EOL .
    "pair list" . PHP_EOL;
    $i = 0;
    foreach($cryptocurrencies as $p) {
        $i++;
        if ($i == 1)    { $usage = $usage . "  " . $p; }
        elseif ($i < 5) { $usage = $usage . ", " . $p; }
        else            { $usage = $usage . ", " . $p . PHP_EOL; $i = 0;}
    }
    fputs(STDERR, $usage . PHP_EOL);
}
